@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: main.c,v 1.28.2.7 2004/06/13 02:35:01 fuyu Exp $
+ * $Id: main.c,v 1.28.2.8 2004/06/13 22:55:27 fuyu Exp $
  */
 
 #include "config.h"
@@ -31,6 +31,7 @@
 #include "ochusha_private.h"
 #include "ochusha.h"
 #include "htmlutils.h"
+#include "monitor.h"
 #include "worker.h"
 #include "utils.h"
 
@@ -61,38 +62,25 @@
 
 
 #if GTK_MINOR_VERSION > 2
-static int lock_depth = 0;
-static GStaticRecMutex ochusha_gdk_threads_lock = G_STATIC_REC_MUTEX_INIT;
+static Monitor *ochusha_gdk_threads_monitor = NULL;
 
 
 static void
 ochusha_gdk_threads_enter(void)
 {
-  g_static_rec_mutex_lock(&ochusha_gdk_threads_lock);
-  lock_depth++;
-#if ENABLE_STRICT_CHECK		/* ѥå */
-  if (lock_depth > 1)
-    fprintf(stderr, "gdk_threads_enter(): depth=%d\n", lock_depth);
-#endif
+  ochusha_monitor_enter(ochusha_gdk_threads_monitor);
 }
 
 
 static void
 ochusha_gdk_threads_leave(void)
 {
-  lock_depth--;
-  g_static_rec_mutex_unlock(&ochusha_gdk_threads_lock);
+  ochusha_monitor_exit(ochusha_gdk_threads_monitor);
 }
 #endif
 
 
-#if DEBUG_GDK_LOCK
-pthread_t volatile last_lock_owner = NULL;
-volatile const char *last_file;
-volatile int last_line;
-#endif
-
-#if USE_THREAD_FOR_MAIN || DEBUG_GDK_LOCK
+#if USE_THREAD_FOR_MAIN
 pthread_t main_thread = NULL;
 #endif
 
@@ -100,9 +88,7 @@ pthread_t main_thread = NULL;
 static void
 real_main(OchushaApplication *application)
 {
-  OCHU_THREADS_ENTER();
-
-  ENTER_MAIN_EVENT_LOOP();
+  gdk_threads_enter();
   gtk_main();
 
 #if TRACE_MEMORY_USAGE
@@ -114,12 +100,7 @@ real_main(OchushaApplication *application)
     }
 #endif
 
-#if 1
-  MAIN_THREAD_EVENT_CALLBACK();	/* ä */
-  OCHU_THREADS_LEAVE();
-#else
   gdk_threads_leave();
-#endif
 }
 #endif
 
@@ -139,6 +120,8 @@ main(int argc, char *argv[])
   init_memory_trace();
 #endif
 
+  ochusha_gdk_threads_monitor = ochusha_monitor_new(NULL);
+
 #if TRACE_REFCOUNT
   init_refcount_trace();
 #endif
@@ -322,13 +305,8 @@ main(int argc, char *argv[])
       abort();
     }
 #else
-# if DEBUG_GDK_LOCK
-  main_thread = pthread_self();
-# endif
 
-  OCHU_THREADS_ENTER();
-
-  ENTER_MAIN_EVENT_LOOP();
+  gdk_threads_enter();
   gtk_main();
 
 # if TRACE_MEMORY_USAGE
@@ -340,12 +318,7 @@ main(int argc, char *argv[])
     }
 # endif
 
-# if 1
-  MAIN_THREAD_EVENT_CALLBACK();	/* ä */
-  OCHU_THREADS_LEAVE();
-# else
   gdk_threads_leave();
-# endif
 #endif
 
   ochusha_network_broker_terminate(application->broker);
@@ -429,6 +402,9 @@ main(int argc, char *argv[])
 
   G_FREE(application);
 
+  ochusha_monitor_free(ochusha_gdk_threads_monitor);
+  ochusha_gdk_threads_monitor = NULL;
+
   dump_pointers();
 #endif
 
@@ -438,19 +414,3 @@ main(int argc, char *argv[])
 
   return 0;
 }
-
-
-#if DEBUG_GDK_LOCK
-void
-ochu_threads_enter(void)
-{
-  OCHU_THREADS_ENTER();
-}
-
-
-void
-ochu_threads_leave(void)
-{
-  OCHU_THREADS_LEAVE();
-}
-#endif
